'use strict';

const fs = require('fs');
const unplugin$1 = require('unplugin');
const pluginutils = require('@rollup/pluginutils');
const context = require('./chunks/context.cjs');
require('mlly');
require('escape-string-regexp');
require('magic-string');
require('local-pkg');

const unplugin = unplugin$1.createUnplugin((options) => {
  const ctx = context.createUnimport(options);
  const filter = pluginutils.createFilter(options.include || [/\.[jt]sx?$/, /\.vue$/, /\.vue\?vue/, /\.svelte$/], options.exclude || [/[\\/]node_modules[\\/]/, /[\\/]\.git[\\/]/]);
  const dts = options.dts === true ? "unimport.d.ts" : options.dts;
  return {
    name: "unimport",
    enforce: "post",
    transformInclude(id) {
      return filter(id);
    },
    async transform(_code) {
      const { code, s } = await ctx.injectImports(_code);
      if (code === _code) {
        return;
      }
      return {
        code,
        map: s.generateMap()
      };
    },
    buildStart() {
      if (dts) {
        return fs.promises.writeFile(dts, ctx.generateTypeDecarations(), "utf-8");
      }
    }
  };
});

module.exports = unplugin;
