import { promises } from 'fs';
import { createUnplugin } from 'unplugin';
import { createFilter } from '@rollup/pluginutils';
import { l as createUnimport } from './chunks/context.mjs';
import 'mlly';
import 'escape-string-regexp';
import 'magic-string';
import 'local-pkg';

const unplugin = createUnplugin((options) => {
  const ctx = createUnimport(options);
  const filter = createFilter(options.include || [/\.[jt]sx?$/, /\.vue$/, /\.vue\?vue/, /\.svelte$/], options.exclude || [/[\\/]node_modules[\\/]/, /[\\/]\.git[\\/]/]);
  const dts = options.dts === true ? "unimport.d.ts" : options.dts;
  return {
    name: "unimport",
    enforce: "post",
    transformInclude(id) {
      return filter(id);
    },
    async transform(_code) {
      const { code, s } = await ctx.injectImports(_code);
      if (code === _code) {
        return;
      }
      return {
        code,
        map: s.generateMap()
      };
    },
    buildStart() {
      if (dts) {
        return promises.writeFile(dts, ctx.generateTypeDecarations(), "utf-8");
      }
    }
  };
});

export { unplugin as default };
